/* A Bison parser, made by GNU Bison 2.5.  */

/* Bison interface for Yacc-like parsers in C
   
      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     REC_SEX_TOK_INT = 258,
     REC_SEX_TOK_REAL = 259,
     REC_SEX_TOK_STR = 260,
     REC_SEX_TOK_NAM = 261,
     REC_SEX_TOK_COLON = 262,
     REC_SEX_TOK_QM = 263,
     REC_SEX_TOK_IMPLIES = 264,
     REC_SEX_TOK_OR = 265,
     REC_SEX_TOK_AND = 266,
     REC_SEX_TOK_GTE = 267,
     REC_SEX_TOK_LTE = 268,
     REC_SEX_TOK_GT = 269,
     REC_SEX_TOK_LT = 270,
     REC_SEX_TOK_NEQ = 271,
     REC_SEX_TOK_EQL = 272,
     REC_SEX_TOK_BEFORE = 273,
     REC_SEX_TOK_AFTER = 274,
     REC_SEX_TOK_SAMETIME = 275,
     REC_SEX_TOK_ADD = 276,
     REC_SEX_TOK_SUB = 277,
     REC_SEX_TOK_MAT = 278,
     REC_SEX_TOK_MOD = 279,
     REC_SEX_TOK_DIV = 280,
     REC_SEX_TOK_MUL = 281,
     REC_SEX_TOK_AMP = 282,
     REC_SEX_TOK_MIN = 283,
     REC_SEX_TOK_NEG = 284,
     REC_SEX_TOK_NOT = 285,
     REC_SEX_TOK_BP = 286,
     REC_SEX_TOK_EP = 287,
     REC_SEX_TOK_ERR = 288,
     REC_SEX_TOK_SHARP = 289
   };
#endif
/* Tokens.  */
#define REC_SEX_TOK_INT 258
#define REC_SEX_TOK_REAL 259
#define REC_SEX_TOK_STR 260
#define REC_SEX_TOK_NAM 261
#define REC_SEX_TOK_COLON 262
#define REC_SEX_TOK_QM 263
#define REC_SEX_TOK_IMPLIES 264
#define REC_SEX_TOK_OR 265
#define REC_SEX_TOK_AND 266
#define REC_SEX_TOK_GTE 267
#define REC_SEX_TOK_LTE 268
#define REC_SEX_TOK_GT 269
#define REC_SEX_TOK_LT 270
#define REC_SEX_TOK_NEQ 271
#define REC_SEX_TOK_EQL 272
#define REC_SEX_TOK_BEFORE 273
#define REC_SEX_TOK_AFTER 274
#define REC_SEX_TOK_SAMETIME 275
#define REC_SEX_TOK_ADD 276
#define REC_SEX_TOK_SUB 277
#define REC_SEX_TOK_MAT 278
#define REC_SEX_TOK_MOD 279
#define REC_SEX_TOK_DIV 280
#define REC_SEX_TOK_MUL 281
#define REC_SEX_TOK_AMP 282
#define REC_SEX_TOK_MIN 283
#define REC_SEX_TOK_NEG 284
#define REC_SEX_TOK_NOT 285
#define REC_SEX_TOK_BP 286
#define REC_SEX_TOK_EP 287
#define REC_SEX_TOK_ERR 288
#define REC_SEX_TOK_SHARP 289




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 2068 of yacc.c  */
#line 92 "rec-sex-tab.y"

  rec_sex_ast_node_t node;
  rec_sex_ast_t ast;



/* Line 2068 of yacc.c  */
#line 125 "rec-sex-tab.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif




